@@ -12,6 +12,7 @@
 
 from openstack.block_storage import _base_proxy
 from openstack.block_storage.v2 import backup as _backup
+from openstack.block_storage.v2 import extension as _extension
 from openstack.block_storage.v2 import quota_set as _quota_set
 from openstack.block_storage.v2 import snapshot as _snapshot
 from openstack.block_storage.v2 import stats as _stats
@@ -22,7 +23,6 @@ from openstack import resource
 
 
 class Proxy(_base_proxy.BaseBlockStorageProxy):
-
     # ====== SNAPSHOTS ======
     def get_snapshot(self, snapshot):
         """Get a single snapshot
@@ -132,8 +132,9 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
 
         :returns: ``None``
         """
-        self._delete(_snapshot.Snapshot, snapshot,
-                     ignore_missing=ignore_missing)
+        self._delete(
+            _snapshot.Snapshot, snapshot, ignore_missing=ignore_missing
+        )
 
     # ====== SNAPSHOT ACTIONS ======
     def reset_snapshot(self, snapshot, status):
@@ -398,9 +399,7 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         volume = self._get_resource(_volume.Volume, volume)
         volume.reset_status(self, status, attach_status, migration_status)
 
-    def attach_volume(
-        self, volume, mountpoint, instance=None, host_name=None
-    ):
+    def attach_volume(self, volume, mountpoint, instance=None, host_name=None):
         """Attaches a volume to a server.
 
         :param volume: The value can be either the ID of a volume or a
@@ -414,9 +413,7 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         volume = self._get_resource(_volume.Volume, volume)
         volume.attach(self, mountpoint, instance, host_name)
 
-    def detach_volume(
-        self, volume, attachment, force=False, connector=None
-    ):
+    def detach_volume(self, volume, attachment, force=False, connector=None):
         """Detaches a volume from a server.
 
         :param volume: The value can be either the ID of a volume or a
@@ -444,8 +441,7 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         volume.unmanage(self)
 
     def migrate_volume(
-        self, volume, host=None, force_host_copy=False,
-        lock_volume=False
+        self, volume, host=None, force_host_copy=False, lock_volume=False
     ):
         """Migrates a volume to the specified host.
 
@@ -466,9 +462,7 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         volume = self._get_resource(_volume.Volume, volume)
         volume.migrate(self, host, force_host_copy, lock_volume)
 
-    def complete_volume_migration(
-        self, volume, new_volume, error=False
-    ):
+    def complete_volume_migration(self, volume, new_volume, error=False):
         """Complete the migration of a volume.
 
         :param volume: The value can be either the ID of a volume or a
@@ -483,7 +477,6 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         volume.complete_migration(self, new_volume, error)
 
     # ====== BACKEND POOLS ======
-
     def backend_pools(self, **query):
         """Returns a generator of cinder Back-end storage pools
 
@@ -584,8 +577,7 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         :returns: ``None``
         """
         if not force:
-            self._delete(
-                _backup.Backup, backup, ignore_missing=ignore_missing)
+            self._delete(_backup.Backup, backup, ignore_missing=ignore_missing)
         else:
             backup = self._get_resource(_backup.Backup, backup)
             backup.force_delete(self)
@@ -617,47 +609,7 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         backup = self._get_resource(_backup.Backup, backup)
         backup.reset(self, status)
 
-    def wait_for_status(self, res, status='available', failures=None,
-                        interval=2, wait=120):
-        """Wait for a resource to be in a particular status.
-
-        :param res: The resource to wait on to reach the specified status.
-            The resource must have a ``status`` attribute.
-        :type resource: A :class:`~openstack.resource.Resource` object.
-        :param status: Desired status.
-        :param failures: Statuses that would be interpreted as failures.
-        :type failures: :py:class:`list`
-        :param interval: Number of seconds to wait before to consecutive
-            checks. Default to 2.
-        :param wait: Maximum number of seconds to wait before the change.
-            Default to 120.
-        :returns: The resource is returned on success.
-        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
-            to the desired status failed to occur in specified seconds.
-        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
-            has transited to one of the failure statuses.
-        :raises: :class:`~AttributeError` if the resource does not have a
-            ``status`` attribute.
-        """
-        failures = ['error'] if failures is None else failures
-        return resource.wait_for_status(
-            self, res, status, failures, interval, wait)
-
-    def wait_for_delete(self, res, interval=2, wait=120):
-        """Wait for a resource to be deleted.
-
-        :param res: The resource to wait on to be deleted.
-        :type resource: A :class:`~openstack.resource.Resource` object.
-        :param interval: Number of seconds to wait before to consecutive
-            checks. Default to 2.
-        :param wait: Maximum number of seconds to wait before the change.
-            Default to 120.
-        :returns: The resource is returned on success.
-        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
-            to delete failed to occur in the specified seconds.
-        """
-        return resource.wait_for_delete(self, res, interval, wait)
-
+    # ====== QUOTA SETS ======
     def get_quota_set(self, project, usage=False, **query):
         """Show QuotaSet information for the project
 
@@ -674,9 +626,9 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         """
         project = self._get_resource(_project.Project, project)
         res = self._get_resource(
-            _quota_set.QuotaSet, None, project_id=project.id)
-        return res.fetch(
-            self, usage=usage, **query)
+            _quota_set.QuotaSet, None, project_id=project.id
+        )
+        return res.fetch(self, usage=usage, **query)
 
     def get_quota_set_defaults(self, project):
         """Show QuotaSet defaults for the project
@@ -691,9 +643,9 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         """
         project = self._get_resource(_project.Project, project)
         res = self._get_resource(
-            _quota_set.QuotaSet, None, project_id=project.id)
-        return res.fetch(
-            self, base_path='/os-quota-sets/defaults')
+            _quota_set.QuotaSet, None, project_id=project.id
+        )
+        return res.fetch(self, base_path='/os-quota-sets/defaults')
 
     def revert_quota_set(self, project, **query):
         """Reset Quota for the project/user.
@@ -707,7 +659,8 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         """
         project = self._get_resource(_project.Project, project)
         res = self._get_resource(
-            _quota_set.QuotaSet, None, project_id=project.id)
+            _quota_set.QuotaSet, None, project_id=project.id
+        )
 
         if not query:
             query = {}
@@ -730,6 +683,7 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
             query = {}
         return res.commit(self, **query)
 
+    # ====== VOLUME METADATA ======
     def get_volume_metadata(self, volume):
         """Return a dictionary of metadata for a volume
 
@@ -776,6 +730,7 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
         else:
             volume.delete_metadata(self)
 
+    # ====== SNAPSHOT METADATA ======
     def get_snapshot_metadata(self, snapshot):
         """Return a dictionary of metadata for a snapshot
 
@@ -823,3 +778,80 @@ class Proxy(_base_proxy.BaseBlockStorageProxy):
                 snapshot.delete_metadata_item(self, key)
         else:
             snapshot.delete_metadata(self)
+
+    # ====== EXTENSIONS ======
+    def extensions(self):
+        """Return a generator of extensions
+
+        :returns: A generator of extension
+        :rtype: :class:`~openstack.block_storage.v3.extension.Extension`
+        """
+        return self._list(_extension.Extension)
+
+    # ====== UTILS ======
+    def wait_for_status(
+        self,
+        res,
+        status='available',
+        failures=None,
+        interval=2,
+        wait=120,
+        callback=None,
+    ):
+        """Wait for a resource to be in a particular status.
+
+        :param res: The resource to wait on to reach the specified status.
+            The resource must have a ``status`` attribute.
+        :type resource: A :class:`~openstack.resource.Resource` object.
+        :param status: Desired status.
+        :param failures: Statuses that would be interpreted as failures.
+        :type failures: :py:class:`list`
+        :param interval: Number of seconds to wait before to consecutive
+            checks. Default to 2.
+        :param wait: Maximum number of seconds to wait before the change.
+            Default to 120.
+        :param callback: A callback function. This will be called with a single
+            value, progress.
+
+        :returns: The resource is returned on success.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
+            to the desired status failed to occur in specified seconds.
+        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
+            has transited to one of the failure statuses.
+        :raises: :class:`~AttributeError` if the resource does not have a
+            ``status`` attribute.
+        """
+        failures = ['error'] if failures is None else failures
+        return resource.wait_for_status(
+            self,
+            res,
+            status,
+            failures,
+            interval,
+            wait,
+            callback=callback,
+        )
+
+    def wait_for_delete(self, res, interval=2, wait=120, callback=None):
+        """Wait for a resource to be deleted.
+
+        :param res: The resource to wait on to be deleted.
+        :type resource: A :class:`~openstack.resource.Resource` object.
+        :param interval: Number of seconds to wait before to consecutive
+            checks. Default to 2.
+        :param wait: Maximum number of seconds to wait before the change.
+            Default to 120.
+        :param callback: A callback function. This will be called with a single
+            value, progress.
+
+        :returns: The resource is returned on success.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
+            to delete failed to occur in the specified seconds.
+        """
+        return resource.wait_for_delete(
+            self,
+            res,
+            interval,
+            wait,
+            callback=callback,
+        )
