@@ -23,8 +23,13 @@ class Volume(resource.Resource, metadata.MetadataMixin):
     base_path = "/volumes"
 
     _query_mapping = resource.QueryParameters(
-        'name', 'status', 'project_id', 'created_at', 'updated_at',
-        all_projects='all_tenants')
+        'name',
+        'status',
+        'project_id',
+        'created_at',
+        'updated_at',
+        all_projects='all_tenants',
+    )
 
     # capabilities
     allow_fetch = True
@@ -48,7 +53,10 @@ class Volume(resource.Resource, metadata.MetadataMixin):
     description = resource.Body("description")
     #: Extended replication status on this volume.
     extended_replication_status = resource.Body(
-        "os-volume-replication:extended_status")
+        "os-volume-replication:extended_status"
+    )
+    #: The ID of the group that the volume belongs to.
+    group_id = resource.Body("group_id")
     #: The volume's current back-end.
     host = resource.Body("os-vol-host-attr:host")
     #: The ID of the image from which you want to create the volume.
@@ -60,6 +68,8 @@ class Volume(resource.Resource, metadata.MetadataMixin):
     #: ``True`` if this volume is encrypted, ``False`` if not.
     #: *Type: bool*
     is_encrypted = resource.Body("encrypted", type=format.BoolStr)
+    #: Whether volume will be sharable or not.
+    is_multiattach = resource.Body("multiattach", type=bool)
     #: The volume ID that this volume's name on the back-end is based on.
     migration_id = resource.Body("os-vol-mig-status-attr:name_id")
     #: The status of this volume's migration (None means that a migration
@@ -69,7 +79,8 @@ class Volume(resource.Resource, metadata.MetadataMixin):
     project_id = resource.Body("os-vol-tenant-attr:tenant_id")
     #: Data set by the replication driver
     replication_driver_data = resource.Body(
-        "os-volume-replication:driver_data")
+        "os-volume-replication:driver_data"
+    )
     #: Status of replication on this volume.
     replication_status = resource.Body("replication_status")
     #: Scheduler hints for the volume
@@ -104,8 +115,9 @@ class Volume(resource.Resource, metadata.MetadataMixin):
         # as both Volume and VolumeDetail instances can be acted on, but
         # the URL used is sans any additional /detail/ part.
         url = utils.urljoin(Volume.base_path, self.id, 'action')
-        resp = session.post(url, json=body,
-                            microversion=self._max_microversion)
+        resp = session.post(
+            url, json=body, microversion=self._max_microversion
+        )
         exceptions.raise_from_response(resp)
         return resp
 
@@ -124,15 +136,15 @@ class Volume(resource.Resource, metadata.MetadataMixin):
         body = {'os-update_readonly_flag': {'readonly': readonly}}
         self._action(session, body)
 
-    def reset_status(
-        self, session, status, attach_status, migration_status
-    ):
+    def reset_status(self, session, status, attach_status, migration_status):
         """Reset volume statuses (admin operation)"""
-        body = {'os-reset_status': {
-            'status': status,
-            'attach_status': attach_status,
-            'migration_status': migration_status
-        }}
+        body = {
+            'os-reset_status': {
+                'status': status,
+                'attach_status': attach_status,
+                'migration_status': migration_status,
+            }
+        }
         self._action(session, body)
 
     def revert_to_snapshot(self, session, snapshot_id):
@@ -141,12 +153,9 @@ class Volume(resource.Resource, metadata.MetadataMixin):
         body = {'revert': {'snapshot_id': snapshot_id}}
         self._action(session, body)
 
-    def attach(
-        self, session, mountpoint, instance=None, host_name=None
-    ):
+    def attach(self, session, mountpoint, instance=None, host_name=None):
         """Attach volume to server"""
-        body = {'os-attach': {
-            'mountpoint': mountpoint}}
+        body = {'os-attach': {'mountpoint': mountpoint}}
 
         if instance is not None:
             body['os-attach']['instance_uuid'] = instance
@@ -154,7 +163,8 @@ class Volume(resource.Resource, metadata.MetadataMixin):
             body['os-attach']['host_name'] = host_name
         else:
             raise ValueError(
-                'Either instance_uuid or host_name must be specified')
+                'Either instance_uuid or host_name must be specified'
+            )
 
         self._action(session, body)
 
@@ -163,8 +173,7 @@ class Volume(resource.Resource, metadata.MetadataMixin):
         if not force:
             body = {'os-detach': {'attachment_id': attachment}}
         if force:
-            body = {'os-force_detach': {
-                'attachment_id': attachment}}
+            body = {'os-force_detach': {'attachment_id': attachment}}
             if connector:
                 body['os-force_detach']['connector'] = connector
 
@@ -178,16 +187,19 @@ class Volume(resource.Resource, metadata.MetadataMixin):
 
     def retype(self, session, new_type, migration_policy=None):
         """Change volume type"""
-        body = {'os-retype': {
-            'new_type': new_type}}
+        body = {'os-retype': {'new_type': new_type}}
         if migration_policy:
             body['os-retype']['migration_policy'] = migration_policy
 
         self._action(session, body)
 
     def migrate(
-        self, session, host=None, force_host_copy=False,
-        lock_volume=False, cluster=None
+        self,
+        session,
+        host=None,
+        force_host_copy=False,
+        lock_volume=False,
+        cluster=None,
     ):
         """Migrate volume"""
         req = dict()
@@ -206,9 +218,12 @@ class Volume(resource.Resource, metadata.MetadataMixin):
 
     def complete_migration(self, session, new_volume_id, error=False):
         """Complete volume migration"""
-        body = {'os-migrate_volume_completion': {
-            'new_volume': new_volume_id,
-            'error': error}}
+        body = {
+            'os-migrate_volume_completion': {
+                'new_volume': new_volume_id,
+                'error': error,
+            }
+        }
 
         self._action(session, body)
 
@@ -219,8 +234,14 @@ class Volume(resource.Resource, metadata.MetadataMixin):
         self._action(session, body)
 
     def upload_to_image(
-        self, session, image_name, force=False, disk_format=None,
-        container_format=None, visibility=None, protected=None
+        self,
+        session,
+        image_name,
+        force=False,
+        disk_format=None,
+        container_format=None,
+        visibility=None,
+        protected=None,
     ):
         """Upload the volume to image service"""
         req = dict(image_name=image_name, force=force)
