@@ -10,7 +10,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from openstack.network import network_service
 from openstack import resource
 
 
@@ -18,12 +17,13 @@ class QoSMinimumBandwidthRule(resource.Resource):
     resource_key = 'minimum_bandwidth_rule'
     resources_key = 'minimum_bandwidth_rules'
     base_path = '/qos/policies/%(qos_policy_id)s/minimum_bandwidth_rules'
-    service = network_service.NetworkService()
+
+    _allow_unknown_attrs_in_body = True
 
     # capabilities
     allow_create = True
-    allow_get = True
-    allow_update = True
+    allow_fetch = True
+    allow_commit = True
     allow_delete = True
     allow_list = True
 
